==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/config-story.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

settype($act, "string");
if ($act == "exportrdf") {
   KWL_ExportRdf();
   $msg = _EXPORT_RDF_NOW1;   
}

$head = _STORYCONT;
include("../include/header.inc.php");

$CONF['FILE_MAX_SIZE'] = KWL_MakeMaxUploadSize($CONF['FILE_MAX_SIZE']);
$VAR["Heading"] = _STORYCONT;

$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<tr>
	<td>". _STORY_ALLOW ."</td>
	<td>". $out->radio("AllowContrib",array(_NOTUSE,_USE),$CONF['AllowContrib']) ."</td>
	</td>
</tr>

<tr>
   <td>". _HTML_PARSE_LEVEL ."</td>
   <td>". $out->select("ParseLevel",array( 0 => _PARSE_L0,
                                           2 => _PARSE_L2,
                                           3 => _PARSE_L3,
                                           4 => _PARSE_L4,
                                           5 => _PARSE_L5 ), $CONF['ParseLevel']) ."
   </td>
</tr>

<tr>
   <td>". _USER_PARSE ."</td>
   <td>". $out->radio("story_parse",array(_NOTUSE,_USE),$CONF['story_parse']) ."</td>
</tr>
   
<tr>
   <td>"._FILEUPLOAD." (<a href=\"attachment.php\">". _LOST_FILES ."</a>)</td>
   <td>". $out->radio("FILE_UPLOAD",array(_NOTUSE,_USE),$CONF['FILE_UPLOAD']) ."
	<br />"._MAXSIZE.": ". $out->input_form("text","FILE_MAX_SIZE",$CONF['FILE_MAX_SIZE'],KWL_FormSize(8),125) ." (". KWL_FileHSize($CONF['FILE_MAX_SIZE']) .")
	<br />
	(php.ini : post_max_size=". ini_get('post_max_size').")
   </td>
</tr>

<tr>
   <td>"._THUMBNAIL."</td>
   <td>". $out->radio("thumbnail",array(_NOTUSE,_USE),$CONF['thumbnail']) ."
	<hr />". _IMAGICK ."
   ". $out->input_form("text","imagick",$CONF['imagick'],KWL_FormSize(15),125)."
   <hr />
   ". _MAX_PIC_PIXEL ."<br />". 
   $out->input_form("text","thumbx",$CONF['thumbx'],KWL_FormSize(3),125)." x ".
   $out->input_form("text","thumby",$CONF['thumby'],KWL_FormSize(3),125)."
   <hr />
   ". _THUMB_SIZE ."<br />".
   $out->input_form("text","thumb_size",$CONF['thumb_size'],KWL_FormSize(3),125)."
   </td>
</tr>

<tr>
   <td>". _ENABLE_EDIT ."</td>
   <td>". $out->radio("ENABLE_EDIT",array(_NOTUSE,_USE),$CONF['ENABLE_EDIT']) ."</td>
</tr>
   
<tr>
	<td>". _STORY_MODER ."</td>
	<td>". $out->radio("Moderation",array( 0 => _NONE,
                                          3 => _NONE ." / ". _NOTIFY,
                                          1 => _USE,
                                          2 => _USE ." / ". _NOTIFY), 
                       $CONF["Moderation"]) ."
	</td>
</tr>

<tr>
	<td>". _SUMMARY_LENGTH ."</td>
	<td>". $out->input_form("text","SummaryLength",$CONF['SummaryLength'],4,4)
	. _CHARACTER ." (0=". _NOTUSE .")</td>
</tr>

<tr>
	<td>". _PAGES ."</td>
   <td>". $out->input_form("text","LimitNews",$CONF['LimitNews'],3,3) ."
   (". _PAGES_DESC .")</td>
</tr>

<tr>
   <td>". _EMAIL_COMMENT ."</td>
   <td>". $out->radio("EmailComments",array(_NOTUSE,_USE),$CONF['EmailComments']) ."
   ("._EMAIL_COMMENT_DESC.")</td>
</tr>

<tr>
   <td>". _ENABLE_BUTTON ."</td>
   <td>". $out->radio("NEXT_PREV",array(_NOTUSE,_USE),$CONF['NEXT_PREV']) ."</td>
</tr>

<tr>
   <td>". _TOPIC_SHOW ."</td>
   <td>". $out->radio("Topics",array(_NOTUSE,_USE),$CONF['Topics']) ."
   &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
   ". _TOPIC_METHO .
   $out->select("TopicSort",array( "id"  => _TOPIC_NOSORT,
                                   "asc" => _TOPIC_ASC,
                                   "desc" => _TOPIC_DESC,
                                   "brief" => _TOPIC_BRIEF), $CONF['TopicSort']) ."
   </td>
</tr>

<tr>
   <td>". _SHOW_NUM ."</td>
   <td>". $out->radio("SHOW_NUM",array(_NOTUSE,_USE),$CONF['SHOW_NUM']) ."</td>
</tr>

<tr>
   <td>". _TOTAL_COUNT_IN_TOPIC ."</td>
   <td>". $out->radio("show_total_num",array(_NOTUSE,_USE),$CONF['show_total_num']) ."</td>
</tr>

<tr>
   <td>". _RDF_USE ."</td>
   <td>". $out->radio("Backend",array(_NOTUSE,_USE),$CONF['Backend']) ."&nbsp;&nbsp;
   [ <a href=\"config-story.php?act=exportrdf\">". _EXPORT_RDF_NOW ."</a> ]
   <br />RSS ". _FILE ." : ". $out->input_form("text","BackendFile",$CONF['BackendFile'],KWL_FormSize(13),128) ."</td>
</tr>

<tr>
	<td>". _MAILTOFRIEND ."</td>
	<td>". $out->radio("MailFriend",array(_NOTUSE,_USE),$CONF['MailFriend']) ."</td>
</tr>

<tr>
	<td>". _PRINTFRIEND ."</td>
	<td>". $out->radio("PrintStory",array(_NOTUSE,_USE),$CONF['PrintStory']) ."</td>
</tr>

<tr>
   <td>"._MAILING_USE."</td>
   <td>". $out->radio("MailingList",array(_NOTUSE,_USE),$CONF['MailingList']) ."
   <br />". _EMAIL .": ". $out->input_form("text","MailingAddress",$CONF['MailingAddress'],KWL_FormSize(13),128) ."</td>
</tr>

<tr>
   <td COLSPAN=2>"
   . $out->input_form("hidden","what","config-story")
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/config-story.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");

$head = _STORYCONT;
include("../include/header.inc.php");

$CONF['FILE_MAX_SIZE'] = KWL_MakeMaxUploadSize($CONF['FILE_MAX_SIZE']);
$VAR["Heading"] = _STORYCONT;

$out = new KWL_Html;
$VAR["Content"] = $out->form_start("admin/submit.php","config")
. $out->table_start("100%",'',1,0,3) ."
<tr>
	<td>". _STORY_ALLOW ."</td>
	<td>". $out->radio("AllowContrib",array(_NOTUSE,_USE),$CONF['AllowContrib']) ."</td>
	</td>
</tr>
<tr>
	<td>". _USERONLY_POST ."</td>
	<td>". $out->radio("useronly_post",array(_NOTUSE,_USE),$CONF['useronly_post']) ."</td>
	</td>
</tr>
<tr>
   <td>". _HTML_PARSE_LEVEL ."</td>
   <td>". $out->select("ParseLevel",array( 0 => _PARSE_L0,
                                           2 => _PARSE_L2,
                                           3 => _PARSE_L3,
                                           4 => _PARSE_L4,
                                           5 => _PARSE_L5 ), $CONF['ParseLevel']) ."
   </td>
</tr>

<tr>
   <td>". _USER_PARSE ."</td>
   <td>". $out->radio("story_parse",array(_NOTUSE,_USE),$CONF['story_parse']) ."</td>
</tr>
   
<tr>
   <td>"._FILEUPLOAD." (<a href=\"attachment.php\">". _LOST_FILES ."</a>)</td>
   <td>". $out->radio("FILE_UPLOAD",array(_NOTUSE,_USE),$CONF['FILE_UPLOAD']) ."
	<br />"._MAXSIZE.": ". $out->input_form("text","FILE_MAX_SIZE",$CONF['FILE_MAX_SIZE'],KWL_FormSize(8),125) ." (". KWL_FileHSize($CONF['FILE_MAX_SIZE']) .")
	<br />
	(php.ini : post_max_size=". ini_get('post_max_size').")
   </td>
</tr>

<tr>
   <td>"._THUMBNAIL."</td>
   <td>". $out->radio("thumbnail",array(_NOTUSE,_USE),$CONF['thumbnail']) ."
	<hr />". _IMAGICK ."
   ". $out->input_form("text","imagick",$CONF['imagick'],KWL_FormSize(15),125)."
   <hr />
   ". _MAX_PIC_PIXEL ."<br />". 
   $out->input_form("text","thumbx",$CONF['thumbx'],KWL_FormSize(3),125)." x ".
   $out->input_form("text","thumby",$CONF['thumby'],KWL_FormSize(3),125)."
   <hr />
   ". _THUMB_SIZE ."<br />".
   $out->input_form("text","thumb_size",$CONF['thumb_size'],KWL_FormSize(3),125)."
   </td>
</tr>

<tr>
   <td>". _ENABLE_EDIT ."</td>
   <td>". $out->radio("ENABLE_EDIT",array(_NOTUSE,_USE),$CONF['ENABLE_EDIT']) ."</td>
</tr>
   
<tr>
	<td>". _STORY_MODER ."</td>
	<td>". $out->radio("Moderation",array( 0 => _NONE,
                                          3 => _NONE ." / ". _NOTIFY,
                                          1 => _USE,
                                          2 => _USE ." / ". _NOTIFY), 
                       $CONF["Moderation"]) ."
	</td>
</tr>

<tr>
	<td>". _SUMMARY_LENGTH ."</td>
	<td>". $out->input_form("text","SummaryLength",$CONF['SummaryLength'],4,4)
	. _CHARACTER ." (0=". _NOTUSE .")</td>
</tr>

<tr>
	<td>". _PAGES ."</td>
   <td>". $out->input_form("text","LimitNews",$CONF['LimitNews'],3,3) ."
   (". _PAGES_DESC .")</td>
</tr>

<tr>
   <td>". _EMAIL_COMMENT ."</td>
   <td>". $out->radio("EmailComments",array(_NOTUSE,_USE),$CONF['EmailComments']) ."
   ("._EMAIL_COMMENT_DESC.")</td>
</tr>

<tr>
   <td>". _ENABLE_BUTTON ."</td>
   <td>". $out->radio("NEXT_PREV",array(_NOTUSE,_USE),$CONF['NEXT_PREV']) ."</td>
</tr>

<tr>
   <td>". _TOPIC_SHOW ."</td>
   <td>". $out->radio("Topics",array(_NOTUSE,_USE),$CONF['Topics']) ."
   &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
   ". _TOPIC_METHO .
   $out->select("TopicSort",array( "id"  => _TOPIC_NOSORT,
                                   "asc" => _TOPIC_ASC,
                                   "desc" => _TOPIC_DESC,
                                   "brief" => _TOPIC_BRIEF), $CONF['TopicSort']) ."
   </td>
</tr>

<tr>
   <td>". _SHOW_NUM ."</td>
   <td>". $out->radio("SHOW_NUM",array(_NOTUSE,_USE),$CONF['SHOW_NUM']) ."</td>
</tr>

<tr>
   <td>". _TOTAL_COUNT_IN_TOPIC ."</td>
   <td>". $out->radio("show_total_num",array(_NOTUSE,_USE),$CONF['show_total_num']) ."</td>
</tr>

<tr>
	<td>". _MAILTOFRIEND ."</td>
	<td>". $out->radio("MailFriend",array(_NOTUSE,_USE),$CONF['MailFriend']) ."</td>
</tr>

<tr>
	<td>". _PRINTFRIEND ."</td>
	<td>". $out->radio("PrintStory",array(_NOTUSE,_USE),$CONF['PrintStory']) ."</td>
</tr>

<tr>
   <td>"._MAILING_USE."</td>
   <td>". $out->radio("MailingList",array(_NOTUSE,_USE),$CONF['MailingList']) ."
   <br />". _EMAIL .": ". $out->input_form("text","MailingAddress",$CONF['MailingAddress'],KWL_FormSize(13),128) ."</td>
</tr>

<tr>
   <td COLSPAN=2>"
   . $out->input_form("hidden","what","config-story")
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>
